@@ -9,6 +9,7 @@ __license__ = "GPL (details at http://www.gnu.org)"
 # std libs
 import re as regex, sys, os, os.path, csv, tempfile, logging, hashlib
 import urllib2 as wget, decimal, StringIO, MimeWriter, mimetypes, mimetools
+import cPickle, zlib
 
 
 # GNUmed libs
@@ -48,8 +49,9 @@ u_one_quarter = u'\u00BC'
 u_one_half = u'\u00BD'
 u_three_quarters = u'\u00BE'
 u_ellipsis = u'\u2026'
-u_left_arrow = u'\u2190'
-u_right_arrow = u'\u2192'
+u_left_arrow = u'\u2190'					# -->
+u_right_arrow = u'\u2192'					# <--
+u_sum = u'\u2211'
 u_corresponds_to = u'\u2258'
 u_infinity = u'\u221E'
 u_diameter = u'\u2300'
@@ -198,7 +200,7 @@ def check_for_update(url=None, current_branch=None, current_version=None, consid
 #===========================================================================
 def handle_uncaught_exception_console(t, v, tb):
 
-	print ",========================================================"
+	print ".========================================================"
 	print "| Unhandled exception caught !"
 	print "| Type :", t
 	print "| Value:", v
@@ -218,7 +220,15 @@ def mkdir(directory=None):
 
 #---------------------------------------------------------------------------
 class gmPaths(gmBorg.cBorg):
+	"""This class provides the following paths:
 
+	.home_dir
+	.local_base_dir
+	.working_dir
+	.user_config_dir
+	.system_config_dir
+	.system_app_data_dir
+	"""
 	def __init__(self, app_name=None, wx=None):
 		"""Setup pathes.
 
@@ -668,7 +678,7 @@ def none_if(value=None, none_equivalent=None):
 		return None
 	return value
 #---------------------------------------------------------------------------
-def coalesce(initial=None, instead=None, template_initial=None, template_instead=None, none_equivalents=None):
+def coalesce(initial=None, instead=None, template_initial=None, template_instead=None, none_equivalents=None, function_initial=None):
 	"""Modelled after the SQL coalesce function.
 
 	To be used to simplify constructs like:
@@ -683,9 +693,55 @@ def coalesce(initial=None, instead=None, template_initial=None, template_instead
 	@type initial: any Python type, must have a __str__ method if template_initial is not None
 	@param instead: the value to be returned if <initial> is None
 	@type instead: any Python type, must have a __str__ method if template_instead is not None
-	@param template_initial: if <initial> is returned replace the value into this template, must contain one <%s> 
+	@param template_initial: if <initial> is returned replace the value into this template, must contain one <%s>
 	@type template_initial: string or None
-	@param template_instead: if <instead> is returned replace the value into this template, must contain one <%s> 
+	@param template_instead: if <instead> is returned replace the value into this template, must contain one <%s>
+	@type template_instead: string or None
+
+	Ideas:
+		- list of insteads: initial, [instead, template], [instead, template], [instead, template], template_initial, ...
+	"""
+	if none_equivalents is None:
+		none_equivalents = [None]
+
+	if initial in none_equivalents:
+
+		if template_instead is None:
+			return instead
+
+		return template_instead % instead
+
+	if function_initial is not None:
+		funcname, args = function_initial
+		func = getattr(initial, funcname)
+		initial = func(args)
+
+	if template_initial is None:
+		return initial
+
+	try:
+		return template_initial % initial
+	except TypeError:
+		return template_initial
+#---------------------------------------------------------------------------
+def old_coalesce(initial=None, instead=None, template_initial=None, template_instead=None, none_equivalents=None):
+	"""Modelled after the SQL coalesce function.
+
+	To be used to simplify constructs like:
+
+		if initial is None (or in none_equivalents):
+			real_value = (template_instead % instead) or instead
+		else:
+			real_value = (template_initial % initial) or initial
+		print real_value
+
+	@param initial: the value to be tested for <None>
+	@type initial: any Python type, must have a __str__ method if template_initial is not None
+	@param instead: the value to be returned if <initial> is None
+	@type instead: any Python type, must have a __str__ method if template_instead is not None
+	@param template_initial: if <initial> is returned replace the value into this template, must contain one <%s>
+	@type template_initial: string or None
+	@param template_instead: if <instead> is returned replace the value into this template, must contain one <%s>
 	@type template_instead: string or None
 
 	Ideas:
@@ -838,6 +894,52 @@ def tex_escape_string(text=None):
 
 	return text
 #===========================================================================
+# image handling tools
+#---------------------------------------------------------------------------
+# builtin (ugly but tried and true) fallback icon
+__icon_serpent = \
+"""x\xdae\x8f\xb1\x0e\x83 \x10\x86w\x9f\xe2\x92\x1blb\xf2\x07\x96\xeaH:0\xd6\
+\xc1\x85\xd5\x98N5\xa5\xef?\xf5N\xd0\x8a\xdcA\xc2\xf7qw\x84\xdb\xfa\xb5\xcd\
+\xd4\xda;\xc9\x1a\xc8\xb6\xcd<\xb5\xa0\x85\x1e\xeb\xbc\xbc7b!\xf6\xdeHl\x1c\
+\x94\x073\xec<*\xf7\xbe\xf7\x99\x9d\xb21~\xe7.\xf5\x1f\x1c\xd3\xbdVlL\xc2\
+\xcf\xf8ye\xd0\x00\x90\x0etH \x84\x80B\xaa\x8a\x88\x85\xc4(U\x9d$\xfeR;\xc5J\
+\xa6\x01\xbbt9\xceR\xc8\x81e_$\x98\xb9\x9c\xa9\x8d,y\xa9t\xc8\xcf\x152\xe0x\
+\xe9$\xf5\x07\x95\x0cD\x95t:\xb1\x92\xae\x9cI\xa8~\x84\x1f\xe0\xa3ec"""
+
+def get_icon(wx=None):
+
+	paths = gmPaths(app_name = u'gnumed', wx = wx)
+
+	candidates = [
+		os.path.join(paths.system_app_data_dir, 'bitmaps', 'gm_icon-serpent_and_gnu.png'),
+		os.path.join(paths.local_base_dir, 'bitmaps', 'gm_icon-serpent_and_gnu.png'),
+		os.path.join(paths.system_app_data_dir, 'bitmaps', 'serpent.png'),
+		os.path.join(paths.local_base_dir, 'bitmaps', 'serpent.png')
+	]
+
+	found_as = None
+	for candidate in candidates:
+		try:
+			open(candidate, 'r').close()
+			found_as = candidate
+			break
+		except IOError:
+			_log.debug('icon not found in [%s]', candidate)
+
+	if found_as is None:
+		_log.warning('no icon file found, falling back to builtin (ugly) icon')
+		icon_bmp_data = wx.BitmapFromXPMData(cPickle.loads(zlib.decompress(__icon_serpent)))
+		icon.CopyFromBitmap(icon_bmp_data)
+	else:
+		_log.debug('icon found in [%s]', found_as)
+		icon = wx.EmptyIcon()
+		try:
+			icon.LoadFile(found_as, wx.BITMAP_TYPE_ANY)		#_PNG
+		except AttributeError:
+			_log.exception(u"this platform doesn't support wx.Icon().LoadFile()")
+
+	return icon
+#===========================================================================
 # main
 #---------------------------------------------------------------------------
 if __name__ == '__main__':
@@ -1137,7 +1239,7 @@ second line\n
 	#test_import_module()
 	#test_mkdir()
 	#test_send_mail()
-	#test_gmPaths()
+	test_gmPaths()
 	#test_none_if()
 	#test_bool2str()
 	#test_bool2subst()
@@ -1146,6 +1248,6 @@ second line\n
 	#test_wrap()
 	#test_input2decimal()
 	#test_unwrap()
-	test_md5()
+	#test_md5()
 
 #===========================================================================
